@@ -91,20 +91,24 @@ def task_fMRI_workflow(name: str, dicom_dir: str, design_block: int, base_dir: s
     # NODE 1: Conversion dicom -> nifti
     conv = Node(CustomDcm2niix(), name='%s_conv' % name)
     conv.inputs.out_filename = name
+    conv.inputs.bids_format = False
     conv.inputs.source_dir = dicom_dir
 
     # NODE 2: Get EPI volume numbers
     nvols = Node(FslNVols(), name="%s_nvols" % name)
+    nvols.long_name = "EPI volumes count"
     workflow.connect(inputnode, 'nvols', nvols, 'force_value')
     workflow.connect(conv, 'converted_files', nvols, 'in_file')
 
     # NODE 3: Get Repetition Time
     getTR = Node(GetNiftiTR(), name="%s_getTR" % name)
+    getTR.long_name = "get TR"
     workflow.connect(inputnode, 'TR', getTR, 'force_value')
     workflow.connect(conv, 'converted_files', getTR, 'in_file')
 
     # NODE 4: Delete specified volumes at start and end of sequence
     del_vols = Node(DeleteVolumes(), name="%s_del_vols" % name)
+    del_vols.long_name = "Extreme volumes deletion"
     workflow.connect(conv, 'converted_files', del_vols, "in_file")
     workflow.connect(nvols, 'nvols', del_vols, "nvols")
     workflow.connect(inputnode, 'del_start_vols', del_vols, "del_start_vols")
@@ -116,6 +120,7 @@ def task_fMRI_workflow(name: str, dicom_dir: str, design_block: int, base_dir: s
 
     # NODE 5: Convert functional images to float representation.
     img2float = Node(ImageMaths(), name="%s_img2float" % name)
+    img2float.long_name = "Intensity in float values"
     img2float.inputs.out_data_type = 'float'
     img2float.inputs.op_string = ''
     img2float.inputs.suffix = '_dtype'
@@ -123,6 +128,7 @@ def task_fMRI_workflow(name: str, dicom_dir: str, design_block: int, base_dir: s
 
     # NODE 6: Extract the middle volume of the first run as the reference
     extract_ref = Node(ExtractROI(), name="%s_extract_ref" % name)
+    extract_ref.long_name = "Reference volume selection"
     extract_ref.inputs.t_size = 1
 
     # Function to extract the middle volume number
@@ -155,6 +161,7 @@ def task_fMRI_workflow(name: str, dicom_dir: str, design_block: int, base_dir: s
 
     # NODE 9: Extract the mean volume of the first functional run
     meanfunc = Node(ImageMaths(), name="%s_meanfunc" % name)
+    meanfunc.long_name = "mean image calculation"
     meanfunc.inputs.op_string = '-Tmean'
     meanfunc.inputs.suffix = '_mean'
     workflow.connect(slice_timing_correction, 'slice_time_corrected_file', meanfunc, 'in_file')
@@ -168,6 +175,7 @@ def task_fMRI_workflow(name: str, dicom_dir: str, design_block: int, base_dir: s
 
     # NODE 11: Mask the functional runs with the extracted mask
     maskfunc = Node(ImageMaths(), name="%s_maskfunc" % name)
+    maskfunc.long_name = "mean image masking"
     maskfunc.inputs.suffix = '_bet'
     maskfunc.inputs.op_string = '-mas'
     workflow.connect(slice_timing_correction, 'slice_time_corrected_file', maskfunc, 'in_file')
@@ -175,11 +183,13 @@ def task_fMRI_workflow(name: str, dicom_dir: str, design_block: int, base_dir: s
 
     # NODE 12: Determine the 2nd and 98th percentile intensities of each functional run
     getthresh = Node(ImageStats(), name="%s_getthresh" % name)
+    getthresh.long_name = "2-98% threshold calculation"
     getthresh.inputs.op_string = '-p 2 -p 98'
     workflow.connect(maskfunc, 'out_file', getthresh, 'in_file')
 
     # NODE 13: Threshold the first run of the functional data at 10% of the 98th percentile
     threshold = Node(ImageMaths(), name="%s_threshold" % name)
+    threshold.long_name = "thresholding"
     threshold.inputs.out_data_type = 'char'
     threshold.inputs.suffix = '_thresh'
 
@@ -193,18 +203,21 @@ def task_fMRI_workflow(name: str, dicom_dir: str, design_block: int, base_dir: s
 
     # NODE 16: Determine the median value of the functional runs using the mask
     medianval = Node(ImageStats(), name="%s_medianval" % name)
+    medianval.long_name = "median value calculation"
     medianval.inputs.op_string = '-k %s -p 50'
     workflow.connect(slice_timing_correction, 'slice_time_corrected_file', medianval, 'in_file')
     workflow.connect(threshold, 'out_file', medianval, 'mask_file')
 
     # NODE 17: Dilate the mask
     dilatemask = Node(ImageMaths(), name="%s_dilatemask" % name)
+    dilatemask.long_name = "Dilate the mask"
     dilatemask.inputs.suffix = '_dil'
     dilatemask.inputs.op_string = '-dilF'
     workflow.connect(threshold, 'out_file', dilatemask, 'in_file')
 
     # NODE 18: Mask the motion corrected functional runs with the dilated mask
     maskfunc2 = Node(ImageMaths(), name="%s_maskfunc2" % name)
+    maskfunc2.long_name = "corrected images masking"
     maskfunc2.inputs.suffix = '_mask'
     maskfunc2.inputs.op_string = '-mas'
     workflow.connect(slice_timing_correction, 'slice_time_corrected_file', maskfunc2, 'in_file')
@@ -212,12 +225,14 @@ def task_fMRI_workflow(name: str, dicom_dir: str, design_block: int, base_dir: s
 
     # NODE 19: Determine the mean image from each functional run
     meanfunc2 = Node(ImageMaths(), name="%s_meanfunc2" % name)
+    meanfunc2.long_name = "Mean image calculation"
     meanfunc2.inputs.op_string = '-Tmean'
     meanfunc2.inputs.suffix = '_mean'
     workflow.connect(maskfunc2, 'out_file', meanfunc2, 'in_file')
 
     # NODE 20: Merge the median values with the mean functional images into a coupled list
     mergenode = Node(Merge(2), name="%s_mergenode" % name)
+    mergenode.long_name = "Mean and median coupling"
     workflow.connect(meanfunc2, 'out_file', mergenode, 'in1')
     workflow.connect(medianval, 'out_stat', mergenode, 'in2')
 
@@ -244,6 +259,7 @@ def task_fMRI_workflow(name: str, dicom_dir: str, design_block: int, base_dir: s
 
     # NODE 22: Mask the smoothed data with the dilated mask
     maskfunc3 = Node(ImageMaths(), name="%s_maskfunc3" % name)
+    maskfunc3.long_name = "denoised images masking"
     maskfunc3.inputs.suffix = '_mask'
     maskfunc3.inputs.op_string = '-mas'
     workflow.connect(smooth, 'smoothed_file', maskfunc3, 'in_file')
@@ -251,6 +267,7 @@ def task_fMRI_workflow(name: str, dicom_dir: str, design_block: int, base_dir: s
 
     # NODE 23: Scale each volume of the run so that the median value of the run is set to 10000
     intnorm = Node(ImageMaths(), name="%s_intnorm" % name)
+    intnorm.long_name = "intensity normalization"
     intnorm.inputs.suffix = '_intnorm'
 
     # Function to get the scaling factor operation string for intensity normalization
@@ -262,6 +279,7 @@ def task_fMRI_workflow(name: str, dicom_dir: str, design_block: int, base_dir: s
 
     # NODE 24: Generate a mean functional image from the first run
     meanfunc3 = Node(ImageMaths(), name="%s_meanfunc3" % name)
+    meanfunc3.long_name = "mean image calculation"
     meanfunc3.inputs.op_string = '-Tmean'
     meanfunc3.inputs.suffix = '_mean'
     workflow.connect(intnorm, 'out_file', meanfunc3, 'in_file')
@@ -279,6 +297,7 @@ def task_fMRI_workflow(name: str, dicom_dir: str, design_block: int, base_dir: s
 
     # NODE 26: Perform temporal highpass filtering on the data
     highpass = Node(ImageMaths(), name="%s_highpass" % name)
+    highpass.long_name = "Highpass temporal filtering"
     highpass.inputs.suffix = '_tempfilt'
     highpass.inputs.suffix = '_hpf'
     workflow.connect(genSpec, 'hpstring', highpass, 'op_string')
@@ -286,6 +305,7 @@ def task_fMRI_workflow(name: str, dicom_dir: str, design_block: int, base_dir: s
 
     # NODE 27: Coregister the mean functional image to the structural image
     flirt_2_ref = Node(FLIRT(), name="%s_flirt_2_ref" % name)
+    flirt_2_ref.long_name = "%s to reference space"
     flirt_2_ref.inputs.out_matrix_file = "fMRI2ref.mat"
     flirt_2_ref.inputs.cost = "corratio"
     flirt_2_ref.inputs.searchr_x = [-90, 90]
@@ -365,11 +385,13 @@ def task_fMRI_workflow(name: str, dicom_dir: str, design_block: int, base_dir: s
         results_select = Node(SelectFiles({'cope': 'cope%d.nii.gz' % cont,
                                                 'zstat': 'zstat%d.nii.gz' % cont}),
                                    name="%s_results_select_%d" % (name, cont))
+        results_select.long_name = "contrast %d result selection" % cont
         workflow.connect(modelestimate, 'results_dir', results_select, 'base_directory')
 
 
         # NODE 35: Mask z-stat with the dilated mask
         maskfunc4 = Node(ImageMaths(), name="%s_maskfunc4_%d" % (name, cont))
+        maskfunc4.long_name = "Zstat masking"
         maskfunc4.inputs.suffix = '_mask'
         maskfunc4.inputs.op_string = '-mas'
         workflow.connect(results_select, 'zstat', maskfunc4, 'in_file')
@@ -377,6 +399,7 @@ def task_fMRI_workflow(name: str, dicom_dir: str, design_block: int, base_dir: s
 
         # NODE 36: Perform clustering on statistical output
         cluster = Node(FslCluster(), name="%s_cluster_%d" % (name, cont))
+        cluster.long_name = "contrast " + str(cont) + " %"
         cluster.inputs.threshold = 3.1
         cluster.inputs.connectivity = 26
         cluster.inputs.pthreshold = 0.05
